@@ -327,7 +327,7 @@ function PMA_openExportFile($filename, $quick_export)
     $save_filename = PMA\libraries\Util::userDir($GLOBALS['cfg']['SaveDir'])
         . preg_replace('@[/\\\\]@', '_', $filename);
 
-    if (file_exists($save_filename)
+    if (@file_exists($save_filename)
         && ((! $quick_export && empty($_REQUEST['onserver_overwrite']))
         || ($quick_export
         && $_REQUEST['quick_export_onserver_overwrite'] != 'saveitover'))
