@@ -8,6 +8,7 @@
 namespace PMA\libraries\navigation\nodes;
 
 use PMA\libraries\Util;
+use PMA\libraries\URL;
 
 /**
  * Represents a database node in the navigation tree
@@ -46,9 +47,9 @@ class NodeDatabase extends Node
         $this->links = array(
             'text'  => $script_name
                 . '?server=' . $GLOBALS['server']
-                . '&amp;db=%1$s&amp;token=' . $_SESSION[' PMA_token '],
+                . '&amp;db=%1$s',
             'icon'  => 'db_operations.php?server=' . $GLOBALS['server']
-                . '&amp;db=%1$s&amp;token=' . $_SESSION[' PMA_token '],
+                . '&amp;db=%1$s&amp;',
             'title' => __('Structure'),
         );
         $this->classes = 'database';
@@ -342,7 +343,7 @@ class NodeDatabase extends Node
             $query .= "'" . $GLOBALS['dbi']->escapeString($searchClause) . "'";
         } else {
             $query .= Util::backquote($columnName) . " LIKE ";
-            $query .= "'%" . $GLOBALS['dbi']->escapeString($searchClause, true)
+            $query .= "'%" . $GLOBALS['dbi']->escapeString($searchClause)
                 . "%'";
         }
 
@@ -459,10 +460,7 @@ class NodeDatabase extends Node
             $query .= "AND `TABLE_TYPE`" . $condition . "'BASE TABLE' ";
             if (! empty($searchClause)) {
                 $query .= "AND `TABLE_NAME` LIKE '%";
-                $query .= $GLOBALS['dbi']->escapeString(
-                    $searchClause,
-                    true
-                );
+                $query .= $GLOBALS['dbi']->escapeString($searchClause);
                 $query .= "%'";
             }
             $query .= "ORDER BY `TABLE_NAME` ASC ";
@@ -477,8 +475,7 @@ class NodeDatabase extends Node
                     "Tables_in_" . $db
                 );
                 $query .= " LIKE '%" . $GLOBALS['dbi']->escapeString(
-                    $searchClause,
-                    true
+                    $searchClause
                 );
                 $query .= "%'";
             }
@@ -550,10 +547,7 @@ class NodeDatabase extends Node
             $query .= "AND `ROUTINE_TYPE`='" . $routineType . "' ";
             if (!empty($searchClause)) {
                 $query .= "AND `ROUTINE_NAME` LIKE '%";
-                $query .= $GLOBALS['dbi']->escapeString(
-                    $searchClause,
-                    true
-                );
+                $query .= $GLOBALS['dbi']->escapeString($searchClause);
                 $query .= "%'";
             }
             $query .= "ORDER BY `ROUTINE_NAME` ASC ";
@@ -564,10 +558,7 @@ class NodeDatabase extends Node
             $query = "SHOW " . $routineType . " STATUS WHERE `Db`='$escdDb' ";
             if (!empty($searchClause)) {
                 $query .= "AND `Name` LIKE '%";
-                $query .= $GLOBALS['dbi']->escapeString(
-                    $searchClause,
-                    true
-                );
+                $query .= $GLOBALS['dbi']->escapeString($searchClause);
                 $query .= "%'";
             }
             $handle = $GLOBALS['dbi']->tryQuery($query);
@@ -636,10 +627,7 @@ class NodeDatabase extends Node
                 . Util::getCollateForIS() . "='$escdDb' ";
             if (!empty($searchClause)) {
                 $query .= "AND `EVENT_NAME` LIKE '%";
-                $query .= $GLOBALS['dbi']->escapeString(
-                    $searchClause,
-                    true
-                );
+                $query .= $GLOBALS['dbi']->escapeString($searchClause);
                 $query .= "%'";
             }
             $query .= "ORDER BY `EVENT_NAME` ASC ";
@@ -650,10 +638,7 @@ class NodeDatabase extends Node
             $query = "SHOW EVENTS FROM $escdDb ";
             if (!empty($searchClause)) {
                 $query .= "WHERE `Name` LIKE '%";
-                $query .= $GLOBALS['dbi']->escapeString(
-                    $searchClause,
-                    true
-                );
+                $query .= $GLOBALS['dbi']->escapeString($searchClause);
                 $query .= "%'";
             }
             $handle = $GLOBALS['dbi']->tryQuery($query);
@@ -686,14 +671,16 @@ class NodeDatabase extends Node
         $cfgRelation = PMA_getRelationsParam();
         if ($cfgRelation['navwork']) {
             if ($this->hiddenCount > 0) {
+                $params = array(
+                    'showUnhideDialog' => true,
+                    'dbName' => $this->real_name,
+                );
                 $ret = '<span class="dbItemControls">'
                     . '<a href="navigation.php'
-                    . PMA_URL_getCommon()
-                    . '&showUnhideDialog=true'
-                    . '&dbName=' . urlencode($this->real_name) . '"'
+                    . URL::getCommon($params) . '"'
                     . ' class="showUnhide ajax">'
                     . Util::getImage(
-                        'lightbulb.png',
+                        'show.png',
                         __('Show hidden items')
                     )
                     . '</a></span>';
