@@ -33,16 +33,15 @@ $GLOBALS['dbi']->selectDb($GLOBALS['db']);
 /**
  * Holds information about the current table
  *
+ * Table::getStatusInfo() does caching by default, but here
+ * we force reading of the current table status
+ * if $reread_info is true (for example, coming from tbl_operations.php
+ * and we just changed the table's storage engine)
+ *
  * @todo replace this by Table
  * @global array $GLOBALS['showtable']
  * @name $showtable
  */
-$GLOBALS['showtable'] = array();
-
-// Table::getStatusInfo() does caching by default, but here
-// we force reading of the current table status
-// if $reread_info is true (for example, coming from tbl_operations.php
-// and we just changed the table's storage engine)
 $GLOBALS['showtable'] = $GLOBALS['dbi']->getTable(
     $GLOBALS['db'],
     $GLOBALS['table']
@@ -85,25 +84,26 @@ if ($showtable) {
         ? $showtable['Auto_increment']
         : '';
 
-    $create_options      = isset($showtable['Create_options'])
+    $create_options_tmp      = isset($showtable['Create_options'])
         ? explode(' ', $showtable['Create_options'])
         : array();
+    $create_options = array();
 
     // export create options by its name as variables into global namespace
     // f.e. pack_keys=1 becomes available as $pack_keys with value of '1'
     unset($pack_keys);
-    foreach ($create_options as $each_create_option) {
+    foreach ($create_options_tmp as $each_create_option) {
         $each_create_option = explode('=', $each_create_option);
         if (isset($each_create_option[1])) {
             // ensure there is no ambiguity for PHP 5 and 7
-            ${$each_create_option[0]} = $each_create_option[1];
+            $create_options[$each_create_option[0]] = $each_create_option[1];
         }
     }
     // we need explicit DEFAULT value here (different from '0')
-    $pack_keys = (! isset($pack_keys) || mb_strlen($pack_keys) == 0)
+    $create_options['pack_keys'] = (! isset($create_options['pack_keys']) || strlen($create_options['pack_keys']) == 0)
         ? 'DEFAULT'
-        : $pack_keys;
-    unset($create_options, $each_create_option);
+        : $create_options['pack_keys'];
+    unset($create_options_tmp, $each_create_option);
 } else {
     $pack_keys = $row_format = null;
 }// end if
